app/soc/models/base.py
changeset 1728 0bda51fe91bf
parent 1308 35b75ffcbb37
child 1809 66aec0241d61
--- a/app/soc/models/base.py	Sat Mar 07 20:26:58 2009 +0000
+++ b/app/soc/models/base.py	Sat Mar 07 20:27:24 2009 +0000
@@ -56,8 +56,8 @@
     props = self.properties()
 
     for key, value in props.iteritems():
-      # Skip everything but StringProperties
-      if not isinstance(value, db.StringProperty):
+      # Skip everything but StringProperties and IntegerProperties
+      if not isinstance(value, (db.StringProperty, db.IntegerProperty)):
         continue
       result[key] = getattr(self, key)